import React from "react";
import { useTranslation } from "react-i18next";
import { Card, CardContent, CardActions, Button } from "@material-ui/core";
import { makeStyles } from "@material-ui/core/styles";
import PageTitle from "../../../../components/PageTitle";
import LanguageContainer from "./LanguageContainer";
import TextField from "@material-ui/core/TextField";
import Autocomplete from "@material-ui/lab/Autocomplete";
import SaveIcon from "@material-ui/icons/Save";

const useStyles = makeStyles((theme) => ({
  root: {
    minWidth: 275
  },
  formControl: {
    margin: theme.spacing(1),
    width: 300
  }
}));

const AppearancePage = () => {
  const [state, setState] = React.useState({ theme: "default" });

  const { t } = useTranslation();
  const classes = useStyles();

  const handleThemeChange = (event, newValue) => {
    setState((prev) => ({ ...prev, theme: newValue }));
  };

  const themes = ["default", "black", "blue"];
  return (
    <>
      <PageTitle title={t("Menu.Appearance")} />
      <Card className={classes.root}>
        <CardContent>
          <LanguageContainer />
          <br />
          <Autocomplete
            id="settings.appearance.theme.autocomplete"
            size="small"
            options={themes}
            value={state.theme}
            onChange={handleThemeChange}
            getOptionLabel={(option) => option}
            className={classes.formControl}
            renderInput={(params) => (
              <TextField {...params} label="Theme" variant="outlined" />
            )}
          />
        </CardContent>
        <CardActions>
          <Button
            variant="contained"
            color="primary"
            size="small"
            startIcon={<SaveIcon />}
          >
            Save
          </Button>
        </CardActions>
      </Card>
    </>
  );
};

export default AppearancePage;
